@@ -31,12 +31,12 @@ from suite_py.lib.tokens import Tokens
     "--project",
     type=click.Path(exists=True),
     default=os.getcwd(),
-    help="Path del progetto su cui eseguire il comando (default directory corrente)",
+    help="Path of the project to run the command on (the default is current directory)",
 )
 @click.option(
     "--timeout",
     type=click.INT,
-    help="Timeout in secondi per le operazioni di CaptainHook",
+    help="Timeout in seconds for Captainhook operations",
 )
 @click.pass_context
 def main(ctx, project, timeout):
@@ -46,15 +46,15 @@ def main(ctx, project, timeout):
     config = Config()
 
     if not git.is_repo(project):
-        print(f"la directory {project} non è un repository git")
+        print(f"the folder {project} is not a git repo")
         sys.exit(-1)
 
     if not os.path.basename(project) in os.listdir(config.user["projects_home"]):
-        print(f"la directory {project} non è in {config.user['projects_home']}")
+        print(f"the folder {project} is not in {config.user['projects_home']}")
         sys.exit(-1)
 
     if not config.user.get("skip_confirmation", False) and not prompt_utils.ask_confirm(
-        f"Vuoi continuare sul progetto {os.path.basename(project)}?"
+        f"Do you want to continue on project {os.path.basename(project)}?"
     ):
         sys.exit()
 
@@ -68,15 +68,15 @@ def main(ctx, project, timeout):
 
 
 @main.command(
-    "create-branch", help="Crea branch locale e imposta la card di YouTrack in progress"
+    "create-branch", help="Create local branch and set the YouTrack card in progress"
 )
-@click.option("--card", type=click.STRING, help="Numero card youtrack (ex. PRIMA-123)")
+@click.option("--card", type=click.STRING, help="YouTrack card number (ex. PRIMA-123)")
 @click.pass_obj
 def cli_create_branch(obj, card):
     CreateBranch(obj["project"], card, obj["config"], obj["tokens"]).run()
 
 
-@main.command("lock", help="Lock di un progetto su staging o prod")
+@main.command("lock", help="Lock project on staging or prod")
 @click.argument(
     "environment", type=click.Choice(("staging", "production", "deploy", "merge"))
 )
@@ -85,7 +85,7 @@ def cli_lock_project(obj, environment):
     ProjectLock(obj["project"], environment, "lock", obj["config"]).run()
 
 
-@main.command("unlock", help="Unlock di un progetto su staging o prod")
+@main.command("unlock", help="Unlock project on staging or prod")
 @click.argument(
     "environment", type=click.Choice(("staging", "production", "deploy", "merge"))
 )
@@ -94,76 +94,76 @@ def cli_unlock_project(obj, environment):
     ProjectLock(obj["project"], environment, "unlock", obj["config"]).run()
 
 
-@main.command("open-pr", help="Apre una PR su GitHub")
+@main.command("open-pr", help="Open a PR on GitHub")
 @click.pass_obj
 def cli_open_pr(obj):
     OpenPR(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("ask-review", help="Chiede la review di una PR")
+@main.command("ask-review", help="Requests a PR review")
 @click.pass_obj
 def cli_ask_review(obj):
     AskReview(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("create-qa", help="Crea un QA (integrazione con qainit)")
+@main.command("create-qa", help="Create QA env (integration with qainit)")
 @click.pass_obj
 def cli_create_qa(obj):
     CreateQA(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("delete-qa", help="Cancella un QA (integrazione con qainit)")
+@main.command("delete-qa", help="Delete QA env (integration with qainit)")
 @click.pass_obj
 def cli_delete_qa(obj):
     DeleteQA(obj["project"], obj["config"], obj["tokens"]).run()
 
 
 @main.command(
-    "merge-pr", help="Merge del branch selezionato con master se tutti i check sono ok"
+    "merge-pr", help="Merge the selected branch to master if all checks are OK"
 )
 @click.pass_obj
 def cli_merge_pr(obj):
     MergePR(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("deploy", help="Deploy in produzione del branch master")
+@main.command("deploy", help="Deploy master branch in production")
 @click.pass_obj
 def cli_deploy(obj):
     Deploy(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("rollback", help="Rollback in produzione")
+@main.command("rollback", help="Rollback in production")
 @click.pass_obj
 def cli_rollback(obj):
     Rollback(obj["project"], obj["config"], obj["tokens"]).run()
 
 
-@main.command("status", help="Stato attuale di un progetto")
+@main.command("status", help="Current status of a project")
 @click.pass_obj
 def cli_status(obj):
     Status(obj["project"], obj["config"]).run()
 
 
-@main.command("check", help="Verifica autorizzazioni ai servizi di terze parti")
+@main.command("check", help="Verify authorisations for third party services")
 @click.pass_obj
 def cli_check(obj):
     Check(obj["config"], obj["tokens"]).run()
 
 
-@main.command("ip", help="Ottieni gli indirizzi IP degli hosts dove il task è running")
+@main.command("ip", help="Get the IP addresses of the hosts where the task is running")
 @click.argument("environment", type=click.Choice(("staging", "production")))
 @click.pass_obj
 def cli_ip(obj, environment):
     IP(obj["project"], environment).run()
 
 
-@main.command("generator", help="Genera diversi file partendo da dei templates")
+@main.command("generator", help="Generate different files from templates")
 @click.pass_obj
 def cli_generator(obj):
     Generator(obj["config"], obj["tokens"]).run()
 
 
-@main.command("aggregator", help="Gestione dei puntamenti dai vari aggregatori ai QA")
+@main.command("aggregator", help="Managem CNAMEs of aggregators in QA envs")
 @click.option("-l", "--list", "show_list", required=False, count=True)
 @click.option("-c", "--change", "change", required=False, count=True)
 @click.pass_obj
