@@ -46,5 +46,10 @@ class IP:
                         for ip in ips:
                             Node(ip, n_service)
 
-        print_tree(n_services, horizontal=True)
+        if n_services.children:
+            print_tree(n_services, horizontal=True)
+        else:
+            logger.info(
+                f"No active tasks for {self._project} in environment {self._env}"
+            )
         logger.info("Done!")
