@@ -46,7 +46,7 @@ class Rollback:
             version = self._ask_version(versions)
             build = self._drone.get_build_from_tag(version)
             self._drone.launch_build(build)
-            logger.info("Build rilanciata, controlla lo stato su drone")
+            logger.info("Build relaunched, check the status on drone")
             self._captainhook.rollback(self._project, version)
 
         else:
@@ -61,21 +61,17 @@ class Rollback:
                     version = self._ask_version(versions)
                     self._rollback_stacks(stacks_name, version)
                 else:
-                    logger.error(
-                        "Nessuna release trovata. Impossibile procedere con il rollback."
-                    )
+                    logger.error("No releases found. Unable to proceed with rollback.")
                     sys.exit(-1)
 
             else:
-                logger.error(
-                    "Nessuno stack trovato. Impossibile procedere con il rollback."
-                )
+                logger.error("No stacks found. Unable to proceed with rollback.")
 
     def _ask_version(self, choiches):
-        version = prompt_utils.ask_choices("Seleziona release: ", choiches)
+        version = prompt_utils.ask_choices("Select release: ", choiches)
         release = self._github.get_release_if_exists(self._repo, version)
-        logger.info(f"\nDescrizione della release selezionata:\n{release.body}\n")
-        if not prompt_utils.ask_confirm("Vuoi continuare con il rollback?"):
+        logger.info(f"\nDescription of the selected release:\n{release.body}\n")
+        if not prompt_utils.ask_confirm("Do you want to continue with the rollback?"):
             sys.exit(-1)
         return version
 
@@ -113,6 +109,4 @@ class Rollback:
     def _rollback_stacks(self, stacks_name, version):
         aws.update_stacks(stacks_name, version)
         self._captainhook.rollback(self._project, version)
-        logger.info(
-            f"Rollback completato con successo. Versione in produzione: {version}"
-        )
+        logger.info(f"Rollback completed successfully. Production version: {version}")
